@@ -6,7 +6,7 @@ import traceback
 from datetime import datetime
 import pandas as pd
 from typing import Tuple
-import exceptions
+import fscloudutils.exceptions as exceptions
 
 
 class NavRowData:
@@ -19,6 +19,12 @@ class NavRowData:
         self._direction_true = None
         self._talkerID = None
 
+    def get_lat(self):
+        return self._lat
+
+    def get_long(self):
+        return self._long
+
     def set_talkerID(self, talkerID):
         self._talkerID = talkerID
 
